# Voltyl - مكتبة تحميل الفيديوهات من يوتيوب

Voltyl هي مكتبة Python تتيح لك تحميل الفيديوهات من يوتيوب باستخدام `yt-dlp`، مع دعم لاستخدام ملفات الكوكيز.

## التثبيت
```sh
pip install voltyl


عيش يصحبي كلو ببلاش لف 